pub enum LambertError {
SingularTransfer,
NoSolution,
ConvergenceFailed,
InvalidInput(&'static str),
}Expand description
Errors returned by lambert.
Variants
SingularTransfer
Transfer angle is exactly 180° — transfer plane undefined.
NoSolution
No solution exists for the given revolution count and time of flight (TOF is below the minimum time for the requested revolution count).
ConvergenceFailed
Householder iteration failed to converge within the iteration limit.
InvalidInput(&'static str)
One or more inputs are invalid (zero radius, non-positive TOF, etc.).